@@ -5,6 +5,7 @@
 #'@param y The target variable
 #'@param xeq The variables to be used in the equilibrium term of the error correction model
 #'@param xtr The variables to be used in the transient term of the error correction model
+#'@param lags The number of lags to use
 #'@param includeIntercept Boolean whether the y-intercept should be included
 #'@param k The number of models or data partitions desired
 #'@param criterion Whether AIC (default), BIC, or adjustedR2 should be used to select variables
@@ -42,7 +43,7 @@
 #'
 #'@export
 #'@importFrom stats lm complete.cases AIC as.formula drop1
-ecmaveback <- function (y, xeq, xtr, includeIntercept = T, criterion = "AIC", k, method = 'boot', seed = 5, weights = NULL, keep = NULL, ...) {
+ecmaveback <- function (y, xeq, xtr, lags=1, includeIntercept = T, criterion = "AIC", k, method = 'boot', seed = 5, weights = NULL, keep = NULL, ...) {
   if (sum(grepl("^delta|Lag1$", names(xtr))) > 0 | sum(grepl("^delta|Lag1$", names(xeq))) > 0) {
     warning("You have column name(s) in xeq or xtr that begin with 'delta' or end with 'Lag1'. It is strongly recommended that you change this, otherwise the function 'ecmpredict' will result in errors or incorrect predictions.")
   }
@@ -51,19 +52,17 @@ ecmaveback <- function (y, xeq, xtr, includeIntercept = T, criterion = "AIC", k,
     stop("xeq or xtr is not of class 'data.frame'. See details on how to input them as data frames.")
   }
   
-  xeqnames <- names(xeq)
-  xeqnames <- paste0(xeqnames, "Lag1")
-  xeq <- as.data.frame(xeq)
-  if (ncol(xeq) > 1) {
-    xeq <- rbind(rep(NA, ncol(xeq)), xeq[1:(nrow(xeq) - 1), ])
-  } else {
-    xeq <- data.frame(c(NA, xeq[1:(nrow(xeq) - 1), ]))
+  if (nrow(xeq) < (lags+1)) {
+    stop("Insufficient data for the lags specified.")
   }
   
+  xeqnames <- names(xeq)
+  xeqnames <- paste0(xeqnames, paste0("Lag", as.character(lags)))
+  xeq <- data.frame(sapply(xeq, lagpad, lags))
+  
   xtrnames <- names(xtr)
   xtrnames <- paste0("delta", xtrnames)
-  xtr <- as.data.frame(xtr)
-  xtr <- data.frame(apply(xtr, 2, diff, 1))
+  xtr <- data.frame(apply(xtr, 2, diff, lags))
   
   if (class(y)=='data.frame'){
     if (ncol(y) > 1){
@@ -71,12 +70,12 @@ ecmaveback <- function (y, xeq, xtr, includeIntercept = T, criterion = "AIC", k,
     }
     y <- y[,1]
   }
-  yLag1 <- y[1:(length(y) - 1)]
+  yLag <- y[1:(length(y) - lags)]
   
   x <- cbind(xtr, xeq[complete.cases(xeq), ])
-  x <- cbind(x, yLag1)
-  names(x) <- c(xtrnames, xeqnames, "yLag1")
-  x$dy <- diff(y, 1)
+  x <- cbind(x, yLag)
+  names(x) <- c(xtrnames, xeqnames, paste0("yLag", as.character(lags)))
+  x$dy <- diff(y, lags)
   
   if (includeIntercept){
     formula <- "dy ~ ."
